# JSON Writer

The JSON writer serializes headerkit IR into JSON, useful for inspection,
debugging, inter-process communication, or as input to custom code generators.

## Writer Class

::: headerkit.writers.json.JsonWriter
    options:
      show_source: false

## Convenience Functions

::: headerkit.writers.json.header_to_json
    options:
      show_source: false

::: headerkit.writers.json.header_to_json_dict
    options:
      show_source: false
